/* Réception des capteurs de 2 MiniWi, configurees sur :
 * le meme port destinataire 8882,
 * deux ports expediteur differents, 1200 et 1202,
 * deux en-tetes differents, /CA et /CB.
 * Ces deux methodes de tri sont alternatives, il n'est pas necessaire de les cumuler au même moment.
 */
/* Receiving data from sensors on 2 Interface-Z MiniWis, set on :
 * destination UDP port 8888
 * 2 different expedition (sending) ports, 1200 and 1202,
 * and 2 different OSC message headers, /CA and /CB.
 * These two sorting methods are alternative, it is not necessary to use both at the same time.
 */

// Importer la librairie oscP5 / Import oscP5 library.
// netP5 est indispensable aussi / net P5 is imported too.
import oscP5.*;
import netP5.*;

// Port reseau UDP, adresse reseau
// Network UDP port, network address
OscP5 oscP5;

// Texte / Text
PFont policeperso, policetitre;

void setup() {
  // Parametres graphiques
  // Visual elements
  size(800, 600);
  background(0);
  noStroke();
  /* Ouverture d'un port pour la reception de messages depuis les MiniWi.
   Un numero de port sert a recevoir des messages venant de l'exterieur. 
   */
  /* Opening a port in order to receive messages from the MiniWi boards. 
   A port number is used to receive messages from the outside. 
   */
  oscP5 = new OscP5(this, 8882);

  policeperso = loadFont("Calibri-28.vlw");
  policetitre = loadFont("Duvall-36.vlw");
}

/**************************************
 Reception des donnees des capteurs
 Receiving sensors data
 **************************************/

// Tableau contenant les valeurs des 4 capteurs analogiques de la premiere MiniWi
// Array containing the 4 analog sensors values from the first MiniWi.
int[] capteurs = new int[4];
// Tableau contenant les etats des 5 capteurs boutons de la premiere MiniWi
// Array containing the 4 switches sensors states from the first MiniWi.
int[] boutons_tries = new int[5];
// Tableau contenant les valeurs des 4 capteurs analogiques de la deuxieme MiniWi
// Array containing the 4 analog sensors values from the second MiniWi.
int[] capteurs2 = new int[4];
// Tableau contenant les etats des 5 capteurs boutons de la deuxieme MiniWi
// Array containing the 4 switches sensors states from the second MiniWi.
int[] boutons_tries2 = new int[5];
// Etat de l'ensemble des boutons d'une miniWi
// State of all switches
int boutons, boutons2 ;

// Gere les messages arrivant des MiniWis
// Manage messages from the MiniWi cards
void oscEvent(OscMessage message_miniwi) {
  // Affiche le port d'expedition / Print the expedition port
  println(message_miniwi.port());
  // Tri sur l'en-tete configure dans les MiniWis
  // Sort the sensors by using the MiniWi header 
  /* if (message_miniwi.checkAddrPattern("/CA")==true) { */
  // OU BIEN :
  // OR :
  // Tri sur le port d'expediteur configure dans les MiniWis
  // Sort the sensors by using the expedition port
  if (message_miniwi.port() == 1202) {  
    // Tri des 4 capteurs analogiques
    // Separating the 4 analog sensors
    for (int i =0; i<4; i++) {
      capteurs[i] = message_miniwi.get(i).intValue();
    }
    boutons = message_miniwi.get(4).intValue();
    // Identification des boutons individuels
    // Les valeurs des capteurs boutons sont 0 ou 1
    // Identifying the 5 switches
    // Switches values are 0 or 1.
    for (int i =0; i<5; i++) {
      boutons_tries[i] = (boutons & int(pow(2, i))) >> i;
    }
  }
  // Tri sur l'en-tete configure dans les MiniWis
  // if (message_miniwi.checkAddrPattern("/CB")==true) {
  // OU BIEN :
  if (message_miniwi.port() == 1200) {  
    // Tri des 4 capteurs analogiques
    for (int i =0; i<4; i++) {
      capteurs2[i] = message_miniwi.get(i).intValue();
    }
    boutons2 = message_miniwi.get(4).intValue();
    // Identification des 5 boutons individuels
    for (int i =0; i<5; i++) {
      boutons_tries2[i] = (boutons2 & int(pow(2, i))) >> i;
    }
  }
}

/**************************************
 Affichage des donnees des capteurs
 Displaying sensors data
 **************************************/

void draw() {  
  background(0);
  fill(70, 190, 220);
  textFont(policetitre, 36);
  text("MiniWi Interface-Z ", 16, 48);
  textFont(policeperso, 28);

  /***** MiniWi 1 *****/
  /*  Affichage des valeurs des capteurs analogiques
   Les valeurs sont affichées sur 409 niveaux et non 4096 pas, pour passer dans l'écran
   */
  /* Displaying analog sensors values.
   Values are shown on 409 steps, not 4096 steps, to appear on a screen.
   */
  // Affichage de 4 Blocs bleus, fond des sliders. / Blue sliders background
  fill(50, 100, 200);
  for (int i=0; i<4; i++) {
    rect(60+(i*30), 80, 20, 409);
    text(i+1, 64+(i*30), 515);
    text((i+1)+" : ", 200, 365 + (i*50));
  }
  // Affichage devant d'un bloc clair dont la hauteur depend de la valeur du capteur
  // Light blue rectangle in front, heigth depending on the sensor's value
  fill(70, 190, 220);
  for (int i=0; i<4; i++) {
    rect(60+(i*30), 489-int(capteurs[i]/10), 20, int(capteurs[i]/10));
    // Ecart en x constant, depart du coin en y variable, largeur x constante, hauteur y variable.
    // x gap constant, start from y corner changing, x width constant, y height changing.
    text(capteurs[i], 250, 365 + (i*50));
  }

  /* Affichage des valeurs des interrupteurs.
   Les valeurs sont affichées en On/Off.
   */
  /* Displaying switches states, On/Off.
   */
  // Affichage de 5 carres bleus, au fond. / 5 blue square in the back.
  fill(50, 100, 200);
  for (int i=0; i<5; i++) {
    rect(200, 80+(i*50), 30, 30);
    text("Bouton "+(i+1), 250, 104+(i*50));
  }
  // Affichage devant d'un bloc clair si le bouton est actif
  // Light square in the front if switch is On.
  fill(70, 190, 220);
  for (int i=0; i<5; i++) {
    rect(200, 80+(i*50), 30*boutons_tries[i], 30*boutons_tries[i]);
    // Ecart en y constant, depart du coin en x variable.
  }


  /***** MiniWi 2 *****/
  // Affichage de 4 Blocs bleus, fond des sliders
  fill(200, 100, 50);
  for (int i=0; i<4; i++) {
    rect(460+(i*30), 80, 20, 409);
    text(i+1, 464+(i*30), 515);
    text((i+1)+" : ", 600, 365 + (i*50));
  }
  // Affichage devant d'un bloc clair dont la hauteur depend de la valeur du capteur
  fill(200, 190, 70);
  for (int i=0; i<4; i++) {
    rect(460+(i*30), 489-int(capteurs2[i]/10), 20, int(capteurs2[i]/10));
    // Ecart en x constant, depart du coin en y variable, largeur x constante, hauteur y variable.
    text(capteurs2[i], 650, 365 + (i*50));
  }

  /* Affichage des valeurs des interrupteurs
   Les valeurs sont affichées en On/Off.
   */
  // Affichage de 5 carres bleus, au fond
  fill(200, 100, 50);
  for (int i=0; i<5; i++) {
    rect(600, 80+(i*50), 30, 30);
    text("Bouton "+(i+1), 650, 104+(i*50));
  }
  // Affichage devant d'un bloc clair si le bouton est actif
  fill(220, 190, 70);
  for (int i=0; i<5; i++) {
    rect(600, 80+(i*50), 30*boutons_tries2[i], 30*boutons_tries2[i]);
    // Ecart en y constant, depart du coin en x variable.
  }
}